from typing import Any, Dict, Literal, Optional, Union, overload
from reflex.vars import Var, BaseVar, ComputedVar
from reflex.event import EventChain, EventHandler, EventSpec
from reflex.style import Style
from typing import Optional, Union, Dict, Any, List, Set
import uuid
from reflex import Component, Var
from reflex.utils import imports
from ..base import AntdComponent, ContainVar, JsValue, ReactNode, ExStateItem, FakeComponentMixin
from ..constant import TypeType
from . import helper

class Modal(AntdComponent):

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

    @overload
    @classmethod
    def create(cls, *children, class_names: Optional[Union[Var[ContainVar], ContainVar]]=None, styles: Optional[Union[Var[ContainVar], ContainVar]]=None, cancel_button_props: Optional[Union[Var[ContainVar], ContainVar]]=None, cancel_text: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, centered: Optional[Union[Var[bool], bool]]=None, close_icon: Optional[Union[Var[Union[str, Component, bool]], Union[str, Component, bool]]]=None, confirm_loading: Optional[Union[Var[bool], bool]]=None, destroy_on_close: Optional[Union[Var[bool], bool]]=None, focus_trigger_after_close: Optional[Union[Var[bool], bool]]=None, footer: Optional[Union[Var[ContainVar], ContainVar]]=None, force_render: Optional[Union[Var[bool], bool]]=None, get_container: Optional[Union[Var[Union[bool, ContainVar]], Union[bool, ContainVar]]]=None, keyboard: Optional[Union[Var[bool], bool]]=None, mask: Optional[Union[Var[bool], bool]]=None, mask_closable: Optional[Union[Var[bool], bool]]=None, modal_render: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, ok_button_props: Optional[Union[Var[ContainVar], ContainVar]]=None, ok_text: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, ok_type: Optional[Union[Var[Literal['default', 'primary']], Literal['default', 'primary']]]=None, title: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, open: Optional[Union[Var[bool], bool]]=None, width: Optional[Union[Var[Union[str, int]], Union[str, int]]]=None, wrapClassName: Optional[Union[Var[str], str]]=None, zIndex: Optional[Union[Var[int], int]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, after_close: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, after_open_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_cancel: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_ok: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Modal':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Confirm(FakeComponentMixin, JsValue):
    config: Optional[Var[dict]]

    @property
    def config_item(self) -> Optional[ExStateItem]:
        ...

    @property
    def uid(self) -> str:
        ...

    def get_name(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

    def serialize(self) -> str:
        ...
modal = Modal.create
confirm = Confirm


from typing import Any, Dict, Literal, Optional, Union, overload
from reflex.vars import Var, BaseVar, ComputedVar
from reflex.event import EventChain, EventHandler, EventSpec
from reflex.style import Style
from typing import Type, Any, Tuple, Dict, List, Iterable, Callable, Set, Union, Optional, Self
import sys
from os import path
from abc import ABC, abstractmethod
from functools import lru_cache, wraps
from hashlib import md5
import uuid
import dataclasses
import inspect
import re
import reflex as rx
from reflex import Component, Var, State, Base
from reflex.base import pydantic
from reflex.components.component import BaseComponent, CustomComponent, StatefulComponent
from reflex.components.base.bare import Bare
from reflex.constants import Hooks, Reflex, MemoizationDisposition, MemoizationMode
from reflex.utils import imports, format
from reflex.vars import BaseVar, VarData
from reflex.event import EventHandler, EventSpec, EventChain
from .constant import SizeType
from .util import OrderedSet
version = '.'.join(map(lambda x: x.zfill(3), Reflex.VERSION.split('.')))
my_path = path.abspath(path.dirname(__file__))
template_path = path.join(my_path, '.templates')
APP_ROUTER = False
RE_KEY_IDX = re.compile('\\.\\d+\\.')
memo_never = MemoizationMode().set(disposition=MemoizationDisposition.NEVER)
memo_never_no_recursive = MemoizationMode().set(disposition=MemoizationDisposition.NEVER, recursive=False)
memo_always = MemoizationMode().set(disposition=MemoizationDisposition.ALWAYS)
memo_always_no_recursive = MemoizationMode().set(disposition=MemoizationDisposition.ALWAYS, recursive=False)

def stateful(hd: Callable[..., Component]=None, forced=True) -> Callable:
    ...

def pretty_dumps(value: Any, indent=2) -> str:
    ...

def get_component_all_imports(com: Component) -> imports.ImportDict:
    ...

def get_component_hooks(com) -> Set[str] | Dict[str, None]:
    ...

def get_component_custom_code(com: Component) -> Set[str]:
    ...

class ExItem(ABC):

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    @abstractmethod
    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_state(self) -> str:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_interpolations(self) -> List[Tuple[int, int]]:
        ...

    def get_var_data(self) -> VarData:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

    def get_custom_code(self) -> set[str]:
        ...

class ExComponentItemBase(ExItem):
    item: Component

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

    def get_custom_code(self) -> set[str]:
        ...

class ExComponentItem(ExComponentItemBase):
    item: Component

class ExStatefulComponentItem(ExComponentItemBase):
    item: StatefulComponent

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

class JsEvent:
    hd: EventHandler
    event_trigger: Callable

    def get_state_full_name(self) -> str:
        ...

    def get_event_args(self) -> str:
        ...

    def get_ex_item(self, parent, key) -> ExItem:
        ...
js_event = JsEvent

class ExEventHandlerItem(ExItem):
    item: JsEvent

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    @property
    def hd_item(self) -> 'ExLambdaHandlerItem':
        ...

    def serialize(self) -> str:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

class ExLambdaHandlerItem(ExItem):
    item: Callable
    event_trigger: Callable

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

class ExCallableItem(ExItem):
    item: Callable

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

class ExStateItem(ExItem):
    item: BaseVar

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_state(self) -> str:
        ...

class FakeComponentMixin:

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

class JsValue:
    value: Callable | str | Component

    def get_ex_item(self, parent, key) -> ExItem:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_state(self) -> str:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_var_data(self) -> VarData:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

class JsFunctionValue(JsValue):

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

def js_value(value: Union[str, Callable, Component], **kwargs) -> JsValue:
    ...

class ExJsItem(ExItem):
    item: JsValue

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

class ExVarItem(ExItem):
    item: Var

    @classmethod
    def isinstance(cls, item: Any) -> bool:
        ...

    def serialize(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_state(self) -> str:
        ...

    def get_interpolations(self) -> List[Tuple[int, int]]:
        ...

class ExFormatter:
    items: List[Type[ExItem]]

    def get_ex_item(self, key: str) -> ExItem | None:
        ...

    def get_value(self) -> str:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...

    def get_state(self) -> str:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_interpolations(self) -> List[Tuple[int, int]]:
        ...

    def get_var_data(self) -> VarData:
        ...

@dataclasses.dataclass(eq=False, **{'slots': True} if sys.version_info >= (3, 10) else {})
class ExVar(BaseVar):
    ...

class NodeVar(ExVar):
    pass

@dataclasses.dataclass(eq=False, **{'slots': True} if sys.version_info >= (3, 10) else {})
class ContainVar(ExVar):

    @classmethod
    def create(cls, _args_: Any=None, **kwargs) -> Self:
        ...

    def init(self, parent: Component, name: str) -> Self:
        ...

    def get_custom_components(self) -> set[CustomComponent]:
        ...

    def get_custom_code(self) -> Set[str]:
        ...

    def get_hooks(self) -> Set[str] | Dict[str, None]:
        ...

    def get_imports(self) -> imports.ImportDict:
        ...
contain = ContainVar.create

def container(data: Union[list, dict], name: str='') -> rx.Component:
    ...

class VarDataMixin:
    ...

class AntdBaseComponent(Component):

    @overload
    @classmethod
    def create(cls, *children, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'AntdBaseComponent':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class AntdComponent(AntdBaseComponent):

    @overload
    @classmethod
    def create(cls, *children, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'AntdComponent':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class AntdSubComponent(AntdBaseComponent, Component):

    @overload
    @classmethod
    def create(cls, *children, base_tag: Optional[str]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'AntdSubComponent':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

def default_config(provider: Component):
    ...

def patch_all():
    ...
ReactNode = Union[str, Component]
JsNode = Union[JsValue, JsEvent]


from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsNode, ReactNode


class TreeSelect(AntdComponent):
    tag = 'TreeSelect'

    allow_clear: Optional[Var[Union[bool, ReactNode]]]
    auto_clear_search_value: Optional[Var[bool]]
    default_value: Optional[Var[Union[str, List[str]]]]
    disabled: Optional[Var[bool]]
    popup_class_name: Optional[Var[str]]
    popup_match_select_width: Optional[Var[Union[bool, int]]]
    dropdown_render: Optional[Var[JsNode]]
    dropdown_style: Optional[Var[Dict]]
    field_names: Optional[Var[Dict]]
    filter_tree_node: Optional[Var[Union[bool, JsNode]]]
    get_popup_container: Optional[Var[JsNode]]
    label_in_value: Optional[Var[bool]]
    list_height: Optional[Var[int]]
    load_data: Optional[Var[JsNode]]
    max_tag_count: Optional[Var[int]]
    max_tag_placeholder: Optional[Var[Union[ReactNode, JsNode]]]
    max_tag_text_length: Optional[Var[int]]
    multiple: Optional[Var[bool]]
    not_found_content: Optional[Var[ReactNode]]
    placeholder: Optional[Var[str]]
    placement: Optional[Var[str]]
    search_value: Optional[Var[str]]
    show_checked_strategy: Optional[Var[str]]
    show_search: Optional[Var[bool]]
    size: Optional[Var[str]]
    status: Optional[Var[str]]
    suffix_icon: Optional[Var[ReactNode]]
    switcher_icon: Optional[Var[Union[ReactNode, ContainVar]]]
    tag_render: Optional[Var[JsNode]]
    tree_checkable: Optional[Var[bool]]
    tree_check_strictly: Optional[Var[bool]]
    tree_data: Optional[Var[List[Dict]]]
    tree_data_simple_mode: Optional[Var[Union[bool, Dict]]]
    tree_default_expand_all: Optional[Var[bool]]
    tree_default_expanded_keys: Optional[Var[List]]
    tree_expand_action: Optional[Var[Union[str, bool]]]
    tree_expanded_keys: Optional[Var[List[str]]]
    tree_icon: Optional[Var[bool]]
    tree_line: Optional[Var[Union[bool, Dict]]]
    tree_loaded_keys: Optional[Var[List[str]]]
    tree_node_filter_prop: Optional[Var[str]]
    tree_node_label_prop: Optional[Var[str]]
    value: Optional[Var[Union[str, List[str]]]]
    variant: Optional[Var[str]]
    virtual: Optional[Var[str]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda value, label, extra: [value, label, extra],
            EventTriggers.ON_SELECT: lambda value, node, extra: [value, node, extra],
            "on_dropdown_visible_change": lambda open: [open],
            "on_search": lambda value: [value],
            "on_tree_expand": lambda keys: [keys],

            "filter_tree_node": lambda node: [node],
            "load_data": lambda node: [node],
        })
        return _triggers


tree_select = TreeSelect.create



from typing import Any, Dict, Literal, Optional, Union, overload
from reflex.vars import Var, BaseVar, ComputedVar
from reflex.event import EventChain, EventHandler, EventSpec
from reflex.style import Style
from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers
from ..base import AntdComponent, ContainVar, JsValue, js_value, ReactNode
from ..constant import StatusType

class Transfer(AntdComponent):

    @overload
    @classmethod
    def create(cls, *children, data_source: Optional[Union[Var[List], List]]=None, disabled: Optional[Union[Var[bool], bool]]=None, selections_icon: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, filter_option: Optional[Union[Var[JsValue], JsValue]]=None, footer: Optional[Union[Var[JsValue], JsValue]]=None, list_style: Optional[Union[Var[Union[Dict, JsValue]], Union[Dict, JsValue]]]=None, locale: Optional[Union[Var[Union[Dict, ContainVar]], Union[Dict, ContainVar]]]=None, one_way: Optional[Union[Var[bool], bool]]=None, operations: Optional[Union[Var[List[str]], List[str]]]=None, operation_style: Optional[Union[Var[Dict], Dict]]=None, pagination: Optional[Union[Var[Union[ContainVar, bool]], Union[ContainVar, bool]]]=None, item_render: Optional[Union[Var[Union[JsValue, ContainVar]], Union[JsValue, ContainVar]]]=None, row_key: Optional[Union[Var[JsValue], JsValue]]=None, select_all_labels: Optional[Union[Var[JsValue], JsValue]]=None, selected_keys: Optional[Union[Var[List[str]], List[str]]]=None, show_search: Optional[Union[Var[bool], bool]]=None, showSelect_all: Optional[Union[Var[bool], bool]]=None, status: Optional[Union[Var[Literal['default', 'success', 'error', 'warning', 'info', 'exception', 'normal', 'active']], Literal['default', 'success', 'error', 'warning', 'info', 'exception', 'normal', 'active']]]=None, target_keys: Optional[Union[Var[List[str]], List[str]]]=None, titles: Optional[Union[Var[ContainVar], ContainVar]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_search: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_select_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Transfer':
        """"""
        ...

    def get_event_triggers(self) -> Dict[str, Any]:
        ...
transfer = Transfer.create


from typing import Optional, Union, Dict, Any, List, Tuple

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue
from ..constant import SizeType, PlacementType, TabsType


class Segmented(AntdComponent):
    tag = 'Segmented'

    block: Optional[Var[bool]]
    default_value: Optional[Var[Union[str, int]]]
    disabled: Optional[Var[bool]]
    options: Optional[Union[List[str], List[int], List[Dict]]]
    size: Optional[Var[SizeType]]
    value: Optional[Var[Union[str, int]]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda value: [value],
        })
        return _triggers


segmented = Segmented.create




from typing import Optional, Union, Dict, Any, List, Tuple

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import SizeType, PlacementType, TabsType


class StatisticBase(AntdComponent):
    prefix: Optional[Var[ReactNode]]
    suffix: Optional[Var[ReactNode]]
    title: Optional[Var[ReactNode]]
    value: Optional[Var[Union[str, int]]]
    value_style: Optional[Var[Dict]]


class Statistic(StatisticBase):
    tag = 'Statistic'

    decimal_separator: Optional[Var[str]]
    formatter: Optional[Var[JsValue]]
    group_separator: Optional[Var[str]]
    loading: Optional[Var[bool]]
    precision: Optional[Var[int]]


class StatisticCountdown(StatisticBase):
    tag = 'Statistic.Countdown'

    format: Optional[Var[str]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_finish": lambda: [],
            EventTriggers.ON_CHANGE: lambda value: [value],
        })
        return _triggers


statistic = Statistic.create
statistic_countdown = StatisticCountdown.create




from typing import Optional, Union, Dict, Any
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, ReactNode, JsValue
from ..constant import TypeType, TriggerType, FloatGroupShapeType

from .badge import Badge


class FloatButton(AntdComponent):
    tag = "FloatButton"

    icon: Optional[Var[ReactNode]]
    description: Optional[Var[ReactNode]]
    tooltip: Optional[Var[Union[ReactNode, JsValue]]]
    type: Optional[Var[TypeType]]
    shape: Optional[Var[FloatGroupShapeType]]
    href: Optional[Var[str]]
    target: Optional[Var[str]]
    badge: Optional[Var[Union[Dict]]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CLICK: lambda: [],
        })
        return _triggers


class FloatGroup(FloatButton):
    tag = "FloatButton.Group"

    open: Optional[Var[bool]]
    trigger: Optional[Var[TriggerType]]
    close_icon: Optional[Var[ReactNode]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_OPEN_CHANGE: lambda open: [open],
        })
        return _triggers


class FloatBackTop(FloatButton):
    tag = "FloatButton.BackTop"

    duration: Optional[Var[int]]
    target: Optional[Var[Union[ReactNode, JsValue]]]
    visibility_height: Optional[Var[int]]


float_button = FloatButton.create
float_group = FloatGroup.create
float_back_top = FloatBackTop.create



from typing import Optional, Union, Dict, Any

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue
from ..constant import OrientationType, DirectionType


class Affix(AntdComponent):
    tag = 'Affix'

    offset_bottom: Optional[Var[int]]
    offset_top: Optional[Var[int]]
    target: Optional[Var[JsValue]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()

        _triggers.update({
            EventTriggers.ON_CHANGE: lambda affixed: [affixed],
        })
        return _triggers


affix = Affix.create






from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var

from ..base import AntdComponent, ContainVar, JsValue, ReactNode


class Card(AntdComponent):
    tag = 'Card'

    actions: Optional[Var[ContainVar]]
    active_tab_key: Optional[Var[str]]
    bordered: Optional[Var[bool]]
    cover: Optional[Var[ReactNode]]
    default_active_tab_key: Optional[Var[str]]
    extra: Optional[Var[ReactNode]]
    hoverable: Optional[Var[bool]]
    loading: Optional[Var[bool]]
    size: Optional[Var[str]]
    tab_bar_extra_content: Optional[Var[ReactNode]]
    tab_list: Optional[Var[list[ContainVar]]]
    title: Optional[Var[ReactNode]]
    type: Optional[Var[str]]
    tab_props: Optional[Var[Union[ContainVar, dict]]]
    class_names: Optional[Var[dict]]
    styles: Optional[Var[dict]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            'on_tab_change': lambda key: [key],
        })
        return _triggers


class CardGrid(AntdComponent):
    tag = 'Card.Grid'

    hoverable: Optional[Var[bool]]


class CardMeta(AntdComponent):
    tag = 'Card.Meta'

    avatar: Optional[Var[ReactNode]]
    description: Optional[Var[ReactNode]]
    title: Optional[Var[ReactNode]]


card = Card.create
card_grid = CardGrid.create
card_meta = CardMeta.create



from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers
from reflex.utils import imports

from ..base import AntdComponent, ContainVar, JsNode, ReactNode
from ..constant import StatusType, SizeType


class Tree(AntdComponent):
    tag = 'Tree'

    allow_drop: Optional[Var[JsNode]]
    auto_expand_parent: Optional[Var[bool]]
    block_node: Optional[Var[bool]]
    checkable: Optional[Var[bool]]
    checked_keys: Optional[Var[Union[List, Dict]]]
    check_strictly: Optional[Var[bool]]
    default_checked_keys: Optional[Var[List[str]]]
    default_expand_all: Optional[Var[bool]]
    default_expanded_keys: Optional[Var[List[str]]]
    default_expand_parent: Optional[Var[bool]]
    default_selected_keys: Optional[Var[List[str]]]
    disabled: Optional[Var[bool]]
    draggable: Optional[Var[Union[bool, JsNode, ContainVar]]]
    expanded_keys: Optional[Var[List[str]]]
    field_names: Optional[Var[Dict]]
    filter_tree_node: Optional[Var[JsNode]]
    height: Optional[Var[int]]
    icon: Optional[Var[Union[ReactNode, JsNode]]]
    load_data: Optional[Var[JsNode]]
    loaded_keys: Optional[Var[List[str]]]
    multiple: Optional[Var[bool]]
    root_style: Optional[Var[Dict]]
    selectable: Optional[Var[bool]]
    selected_keys: Optional[Var[List[str]]]
    show_icon: Optional[Var[bool]]
    show_line: Optional[Var[Union[bool, ContainVar]]]
    switcher_icon: Optional[Var[Union[ReactNode, JsNode]]]
    title_render: Optional[Var[JsNode]]
    tree_data: Optional[Var[List[Dict]]]
    virtual: Optional[Var[bool]]
    # DirectoryTree
    expand_action: Optional[Var[Union[bool, str]]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_check": lambda keys, e: [keys, e],
            "on_drag_end": lambda e: [e.event, e.node],
            "on_drag_enter": lambda e: [e.event, e.node, e.expandedKeys],
            "on_drag_leave": lambda e: [e.event, e.node],
            "on_drag_over": lambda e: [e.event, e.node],
            "on_drag_start": lambda e: [e.event, e.node],
            "on_drop": lambda e: [e.event, e.node, e.dragNode, e.dragNodesKeys],
            "on_expand": lambda keys, e: [keys, e],
            "on_load": lambda keys, e: [keys, e],
            "on_right_click": lambda e: [e.event, e.node],
            "on_select": lambda keys, e: [keys, e],

            "load_data": lambda node: [node],
            "filter_tree_node": lambda node: [node],
        })
        return _triggers


tree = Tree.create






from .antd.anchor import anchor  # noqa
from .antd.breadcrumb import breadcrumb  # noqa
from .antd.dropdown import dropdown, dropdown_button  # noqa
from .antd.menu import menu, MenuItem as MI  # noqa
from .antd.pagination import pagination  # noqa
from .antd.steps import steps  # noqa




from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import OrientationType, SizeType


class Drawer(AntdComponent):
    tag = 'Drawer'

    auto_focus: Optional[Var[bool]]
    class_name: Optional[Var[str]]
    class_names: Optional[Var[ContainVar]]
    close_icon: Optional[Var[Union[ReactNode, bool]]]
    destroy_on_close: Optional[Var[bool]]
    extra: Optional[Var[ReactNode]]
    footer: Optional[Var[ReactNode]]
    force_render: Optional[Var[bool]]
    get_container: Optional[Var[Union[ContainVar, bool]]]
    height: Optional[Var[Union[str, int]]]
    keyboard: Optional[Var[bool]]
    mask: Optional[Var[bool]]
    mask_closable: Optional[Var[bool]]
    placement: Optional[Var[OrientationType]]
    push: Optional[Var[Union[bool, dict]]]
    root_style: Optional[Var[dict]]
    size: Optional[Var[SizeType]]
    styles: Optional[Var[ContainVar]]
    title: Optional[Var[ReactNode]]
    open: Optional[Var[bool]]
    width: Optional[Var[Union[str, int]]]
    z_index: Optional[Var[int]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "after_open_change": lambda open: [open],
            "on_close": lambda e: [e],
        })
        return _triggers


drawer = Drawer.create



from typing import Optional, Union, Dict, Any, List, Tuple

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import DatePickerModeType, DatePickerType, SizeType, PlacementType, StatusType, VariantType

from .base import Locale


class DayJS(JsValue):
    def serialize(self) -> str:
        return f"dayjs('{self.value}')"


class BaseDatePicker(AntdComponent):

    allow_clear: Optional[Var[bool]]
    auto_focus: Optional[Var[bool]]
    date_render: Optional[Var[JsValue]]
    cell_render: Optional[Var[JsValue]]
    components: Optional[Var[Union[ReactNode, list, dict, ContainVar]]]
    disabled: Optional[Var[bool]]
    disabled_date: Optional[Var[JsValue]]
    format: Optional[Var[ContainVar]]
    order: Optional[Var[bool]]
    popup_class_name: Optional[Var[str]]
    preserve_invalidOn_blur: Optional[Var[bool]]
    getPopup_container: Optional[Var[JsValue]]
    input_readOnly: Optional[Var[bool]]
    locale: Optional[Var[Locale]]
    min_date: Optional[Var[JsValue]]
    max_date: Optional[Var[JsValue]]
    mode: Optional[Var[DatePickerModeType]]
    need_confirm: Optional[Var[bool]]
    next_icon: Optional[Var[ReactNode]]
    open: Optional[Var[bool]]
    panel_render: Optional[Var[JsValue]]
    picker: Optional[Var[DatePickerType]]
    placeholder: Optional[Var[Union[str, List[str]]]]
    placement: Optional[Var[PlacementType]]
    popup_style: Optional[Var[ContainVar]]
    presets: Optional[Var[ContainVar]]
    prev_icon: Optional[Var[ReactNode]]
    size: Optional[Var[SizeType]]
    status: Optional[Var[StatusType]]
    suffix_icon: Optional[Var[ReactNode]]
    super_next_icon: Optional[Var[ReactNode]]
    super_prev_icon: Optional[Var[ReactNode]]
    variant: Optional[Var[VariantType]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_OPEN_CHANGE: lambda open: [open],
            'on_panel_change': lambda value, mode: [value, mode],
        })
        return _triggers

    def _get_imports(self) -> imports.ImportDict:
        _imports = super()._get_imports()
        _imports.setdefault("dayjs", []).append(
            imports.ImportVar(tag="dayjs", is_default=True, install=False),
        )
        return _imports


class DatePicker(BaseDatePicker):
    tag = 'DatePicker'

    default_picker_value: Optional[Var[JsValue]]
    default_value: Optional[Var[ContainVar]]
    disabled_time: Optional[Var[JsValue]]
    format: Optional[Var[ContainVar]]
    multiple: Optional[Var[bool]]
    picker_value: Optional[Var[ContainVar]]
    render_extra_footer: Optional[Var[JsValue]]
    show_now: Optional[Var[bool]]
    show_time: Optional[Var[Union[bool, ContainVar]]]
    # showTime.defaultValue
    show_week: Optional[Var[bool]]
    value: Optional[Var[ContainVar]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda date, sdate: [date, sdate],
            "on_ok": lambda: [],
            "on_panel_change": lambda value, mode: [value, mode],
        })
        return _triggers


class RangePicker(BaseDatePicker):
    tag = 'RangePicker'

    allow_empty: Optional[Var[Tuple[bool, bool]]]
    cell_render: Optional[Var[JsValue]]
    date_render: Optional[Var[JsValue]]
    default_picker_value: Optional[Var[ContainVar]]
    default_value: Optional[Var[ContainVar]]
    disabled: Optional[Var[Tuple[bool, bool]]]
    disabled_time: Optional[Var[JsValue]]
    format: Optional[Var[ContainVar]]
    id: Optional[Var[Dict[str, str]]]
    picker_value: Optional[Var[ContainVar]]
    presets: Optional[Var[ContainVar]]
    render_extra_footer: Optional[Var[JsValue]]
    separator: Optional[Var[ReactNode]]
    show_time: Optional[Var[Union[bool, ContainVar]]]
    # showTime.defaultValue
    value: Optional[Var[ContainVar]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_calendar_change": lambda dates, sdates, info: [dates, sdates, info],
            EventTriggers.ON_CHANGE: lambda dates, sdates: [dates, sdates],
            EventTriggers.ON_FOCUS: lambda ev, range: [ev, range],
            EventTriggers.ON_BLUR: lambda ev, range: [ev, range],
        })
        return _triggers

    def _get_imports(self) -> imports.ImportDict:
        _imports = super()._get_imports()
        _vars: List = [v for v in _imports[self.library] if v.tag != "RangePicker"]
        _vars.append(
            imports.ImportVar(tag="DatePicker"),
        )
        _imports[self.library] = _vars

        return _imports

    def _get_hooks(self) -> str | None:
        return "const { RangePicker } = DatePicker;"


dayjs = DayJS
date_picker = DatePicker.create
range_picker = RangePicker.create



from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import StatusType, SizeType, SelectModeType, PlacementType, VariantType


class Select(AntdComponent):
    tag = 'Select'

    allow_clear: Optional[Var[bool]]
    auto_clear_search_value: Optional[Var[bool]]
    auto_focus: Optional[Var[bool]]
    default_active_first_option: Optional[Var[bool]]
    default_open: Optional[Var[bool]]
    default_value: Optional[Var[Union[int, str, List[str], List[int], ContainVar]]]
    disabled: Optional[Var[bool]]
    popup_class_name: Optional[Var[str]]
    popup_match_select_width: Optional[Var[Union[bool, int]]]
    dropdown_render: Optional[Var[JsValue]]
    dropdown_style: Optional[Var[Dict]]
    field_names: Optional[Var[Dict]]
    filter_option: Optional[Var[Union[bool, JsValue]]]
    filter_sort: Optional[Var[JsValue]]
    get_popup_container: Optional[Var[JsValue]]
    label_in_value: Optional[Var[bool]]
    list_height: Optional[Var[int]]
    loading: Optional[Var[bool]]
    max_count: Optional[Var[int]]
    max_tag_count: Optional[Var[Union[int, str]]]
    max_tag_placeholder: Optional[Var[Union[ReactNode, JsValue]]]
    max_tag_text_length: Optional[Var[int]]
    menu_item_selected_icon: Optional[Var[ReactNode]]
    mode: Optional[Var[SelectModeType]]
    not_found_content: Optional[Var[ReactNode]]
    open: Optional[Var[bool]]
    option_filter_prop: Optional[Var[str]]
    option_label_prop: Optional[Var[str]]
    options: Optional[Var[Union[list, ContainVar]]]
    option_render: Optional[Var[JsValue]]
    placeholder: Optional[Var[ReactNode]]
    placement: Optional[Var[PlacementType]]
    remove_icon: Optional[Var[ReactNode]]
    search_value: Optional[Var[str]]
    show_search: Optional[Var[bool]]
    size: Optional[Var[SizeType]]
    status: Optional[Var[StatusType]]
    suffix_icon: Optional[Var[ReactNode]]
    tag_render: Optional[Var[JsValue]]
    label_render: Optional[Var[JsValue]]
    token_separators: Optional[Var[List[str]]]
    value: Optional[Var[Union[str, int, List[str], List[int], ContainVar]]]
    variant: Optional[Var[VariantType]]
    virtual: Optional[Var[bool]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda v, option: [v, option],
            "on_clear": lambda: [],
            "on_deselect": lambda v: [v],
            "on_dropdown_visible_change": lambda open: [open],
            "on_input_key_down": lambda: [],
            "on_popup_scroll": lambda: [],
            "on_search": lambda v: [v],
            "on_select": lambda v, option: [v, option],
        })
        return _triggers


select = Select.create




from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, js_value, ReactNode
from ..constant import StatusType


class Transfer(AntdComponent):
    tag = 'Transfer'
    _rename_props: Dict[str, str] = {"itemRender": "render"}

    data_source: Optional[Var[List]]
    disabled: Optional[Var[bool]]
    selections_icon: Optional[Var[ReactNode]]
    filter_option: Optional[Var[JsValue]]
    footer: Optional[Var[JsValue]]
    list_style: Optional[Var[Union[Dict, JsValue]]]
    locale: Optional[Var[Union[Dict, ContainVar]]]
    one_way: Optional[Var[bool]]
    operations: Optional[Var[List[str]]]
    operation_style: Optional[Var[Dict]]
    pagination: Optional[Var[Union[bool, ContainVar]]]
    item_render: Optional[Var[Union[JsValue, ContainVar]]]
    row_key: Optional[Var[JsValue]]
    select_all_labels: Optional[Var[JsValue]]
    selected_keys: Optional[Var[List[str]]]
    show_search: Optional[Var[bool]]
    showSelect_all: Optional[Var[bool]]
    status: Optional[Var[StatusType]]
    target_keys: Optional[Var[List[str]]]
    titles: Optional[Var[ContainVar]]

    @classmethod
    def create(cls, *children, **props) -> Component:
        if 'item_render' not in props:
            props['item_render'] = js_value(lambda record: 'return record.title;')
        com = super().create(*children, **props)
        return com

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda target_keys, direction, move_keys: [target_keys, direction, move_keys],
            EventTriggers.ON_SCROLL: lambda direction, ev: [direction, ev],
            "on_search": lambda direction, value: [direction, value],
            "on_select_change": lambda s_keys, t_keys: [s_keys, t_keys],
        })
        return _triggers


transfer = Transfer.create







import uuid
from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component

from ..base import (AntdComponent, ContainVar, JsValue, ReactNode, js_value,
                    memo_never_no_recursive, memo_always_no_recursive)
from ..constant import AlignType, DirectionType, SizeType, VariantType


class Form(AntdComponent):
    tag = 'Form'

    colon: Optional[Var[bool]]
    disabled: Optional[Var[bool]]
    fields: Optional[Var[ContainVar]]
    form: Optional[Var[str]]
    initial_values: Optional[Var[Dict]]
    label_align: Optional[Var[AlignType]]
    label_wrap: Optional[Var[bool]]
    label_col: Optional[Var[Dict]]
    layout: Optional[Var[DirectionType]]
    name: Optional[Var[str]]
    preserve: Optional[Var[bool]]
    required_mark: Optional[Var[Union[bool, JsValue]]]
    scrollTo_first_error: Optional[Var[Union[bool, Dict]]]
    size: Optional[Var[SizeType]]
    validate_messages: Optional[Var[Dict]]
    validate_trigger: Optional[Var[Union[str, List[str]]]]
    variant: Optional[Var[VariantType]]
    wrapper_col: Optional[Var[Dict]]

    # form and form.item can not split, if split some components like select don't work;
    _memoization_mode = memo_never_no_recursive

    @classmethod
    def create(cls, *children, **props) -> Component:
        if 'form' in props and isinstance(props['form'], str):
            props['form'] = Var.create_safe(f'{props["form"]}', _var_is_local=False)
        comp = super().create(*children, **props)
        if comp._get_all_hooks() or comp._get_all_hooks_internal():
            comp._memoization_mode = memo_always_no_recursive
        return comp

    def _get_hooks(self) -> str | None:
        if hasattr(self, 'form') and self.form is not None:
            return f"const [{str(self.form).strip('{}')}] = Form.useForm();"

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_fields_change": lambda changed, all: [changed],
            'on_finish': lambda values: [values],
            "on_finish_failed": lambda ev: [ev.values, ev.errorFields, ev.outOfDate],
            "on_values_change": lambda changed, all: [changed, all],
        })
        return _triggers


class FormItem(AntdComponent):
    tag = 'Form.Item'

    colon: Optional[Var[bool]]
    dependencies: Optional[Var[List[Union[str, int, List[Union[str, int]]]]]]
    extra: Optional[Var[ReactNode]]
    getValue_from_event: Optional[Var[JsValue]]
    get_value_props: Optional[Var[JsValue]]
    has_feedback: Optional[Var[Union[bool, ContainVar]]]
    help: Optional[Var[ReactNode]]
    hidden: Optional[Var[bool]]
    html_for: Optional[Var[str]]
    initial_value: Optional[Var[str]]
    label: Optional[Var[str]]
    label_align: Optional[Var[AlignType]]
    label_col: Optional[Var[Dict]]
    message_variables: Optional[Var[JsValue]]
    name: Optional[Var[Union[str, int, List[Union[str, int]]]]]
    normalize: Optional[Var[JsValue]]
    no_style: Optional[Var[bool]]
    preserve: Optional[Var[bool]]
    required: Optional[Var[bool]]
    rules: Optional[Var[Union[List[Dict], ContainVar]]]
    should_update: Optional[Var[bool]]
    tooltip: Optional[Var[Union[Component, ContainVar]]]
    trigger: Optional[Var[str]]
    validate_debounce: Optional[Var[float]]
    validate_first: Optional[Var[Union[bool, str]]]
    validate_status: Optional[Var[str]]
    validate_trigger: Optional[Var[Union[str, List[str]]]]
    value_prop_name: Optional[Var[str]]
    wrapper_col: Optional[Var[Dict]]


class FormList(AntdComponent):
    tag = 'Form.List'

    # children: Optional[Var[JsValue]]
    initial_value: Optional[Var[List]]
    name: Optional[Var[Union[str, int, List[Union[str, int]]]]]
    rules: Optional[Var[ContainVar]]


class FormProvider(AntdComponent):
    tag = 'Form.Provider'

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_form_change": lambda form_name, info: [form_name, info],
            'on_form_finish': lambda form_name, info: [form_name, info],
        })
        return _triggers


form = Form.create
form_item = FormItem.create
form_list = FormList.create
form_provider = FormProvider.create


def _modal_form(modal_type: str, *children, modal_config=None, form_id: str = None, **props) -> JsValue | Component:
    from . import modal
    if form_id is None:
        form_id = f'form_{uuid.uuid4().hex}'
    props.update(
        form=form_id,
        preserve=False,
    )
    f = form(*children, **props)
    f._memoization_mode = memo_never_no_recursive

    modal_config = modal_config or {}
    modal_config.update(destroy_on_close=True)
    modal_config['on_ok'] = js_value(f"""() => {{
        return new Promise((resolve, reject) => {{
    {form_id}
      .validateFields({{
        validateOnly: false,
      }})
      .then(() => {{
        {form_id}.submit();
      resolve()}})
      .catch(() => {{
      reject()}});
      }});//if catch, modal will close the form //.catch(() => console.log('Oops errors!'));
      }}
    """)
    op = getattr(modal, modal_type)
    if modal_type == 'confirm':
        modal_config['content'] = f
        return op(config=modal_config)
    else:
        modal_config['after_open_change'] = js_value(f"""(open) => {{{form_id}.resetFields()}}""")
        modal = op(
            f,
            # on_open=JsValue(f'{form_id}.resetFields()'),
            **modal_config)
        return modal


def modal_form(*children, modal_config=None, form_id: str = None, **props) -> Component:
    return _modal_form('modal',
                       *children, modal_config=modal_config, form_id=form_id, **props)


def confirm_form(*children, confirm_config=None, form_id: str = None, **props) -> JsValue:
    return _modal_form('confirm',
                       *children, modal_config=confirm_config, form_id=form_id, **props)



from typing import Optional, Union, Dict, Any, List
from reflex import Var
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar
from ..constant import StatusType, SizeType


class Checkbox(AntdComponent):
    tag = "Checkbox"

    auto_focus: Optional[Var[bool]]
    checked: Optional[Var[bool]]
    default_checked: Optional[Var[bool]]
    disabled: Optional[Var[bool]]
    indeterminate: Optional[Var[bool]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda e: [e],
        })
        return _triggers


class CheckboxGroup(AntdComponent):
    tag = 'Checkbox.Group'

    default_value: Optional[Var[List[Union[int, str]]]]
    disabled: Optional[Var[bool]]
    name: Optional[Var[str]]
    options: Optional[Var[List[Union[str, int, Dict]]]]
    value: Optional[Var[List[Union[int, str, bool]]]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda checked_value: [checked_value],
        })
        return _triggers


checkbox = Checkbox.create
checkbox_group = CheckboxGroup.create






from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import StatusType, SizeType, VariantType, PlacementType


class Mention(AntdComponent):
    tag = 'Mention'

    allow_clear: Optional[Var[Union[bool, ContainVar]]]
    auto_focus: Optional[Var[bool]]
    auto_size: Optional[Var[Union[bool, Dict]]]
    default_value: Optional[Var[str]]
    filter_option: Optional[Var[Union[bool, JsValue]]]
    get_popup_container: Optional[Var[JsValue]]
    not_found_content: Optional[Var[ReactNode]]
    placement: Optional[Var[PlacementType]]
    prefix: Optional[Var[Union[str, List[str]]]]
    split: Optional[Var[str]]
    status: Optional[Var[StatusType]]
    validate_search: Optional[Var[JsValue]]
    value: Optional[Var[str]]
    variant: Optional[Var[VariantType]]
    options: Optional[Var[ContainVar]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda text: [text],
            "on_resize": lambda ev: [ev],
            'on_search': lambda text, prefix: [text, prefix],
            "on_select": lambda option, prefix: [option, prefix],
        })
        return _triggers


mention = Mention.create



from typing import Optional, Union, Dict, Any, List, Tuple

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue
from ..constant import SizeType, QRCodeType, QRCodeErrorLevelType, QRCodeStatusType


class QRCode(AntdComponent):
    tag = 'QRCode'

    value: Optional[Var[str]]
    type: Optional[Var[QRCodeType]]
    icon: Optional[Var[str]]
    size: Optional[Var[int]]
    icon_size: Optional[Var[int]]
    color: Optional[Var[str]]
    bg_color: Optional[Var[str]]
    bordered: Optional[Var[bool]]
    error_level: Optional[Var[QRCodeErrorLevelType]]
    status: Optional[Var[QRCodeStatusType]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_refresh": lambda: [],
        })
        return _triggers


qrcode = QRCode.create




from typing import Optional, Union, Type, Dict, List, Any, Iterator
from reflex import Component, Var, EventChain, Base
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, ReactNode, pydantic
from ..constant import ThemeType, DirectionType, TriggerType


class MenuItem(pydantic.BaseModel):
    key: str
    label: str
    icon: Component
    children: Optional[List["MenuItem"]] = None


# class MenuItems(ContainVar):
#     pass

class OnSelectEvent(Base):
    item: Any
    key: Any
    keyPath: Any
    selectedKeys: List[str]


class Menu(AntdComponent):
    tag = 'Menu'

    default_open_keys: Optional[Var[List[str]]]
    default_selected_keys: Optional[Var[List[str]]]
    expand_icon: Optional[Var[ReactNode]]
    force_sub_menu_render: Optional[Var[bool]]
    inline_collapsed: Optional[Var[bool]]
    inline_indent: Optional[Var[bool]]

    items: Var[Union[ContainVar, list]]
    mode: Optional[Var[DirectionType]]
    multiple: Optional[Var[bool]]
    open_keys: Optional[Var[List[str]]]
    overflowed_indicator: Optional[Var[ReactNode]]
    selectable: Optional[Var[bool]]
    selected_keys: Optional[Var[List[str]]]
    sub_menu_close_delay: Optional[Var[float]]
    sub_menu_open_delay: Optional[Var[float]]

    theme: Optional[Var[ThemeType]]
    trigger_sub_menu_action: Optional[Var[TriggerType]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()

        def _on_select(ev: OnSelectEvent):
            return [ev.selectedKeys]

        def _on_click(ev: OnSelectEvent):
            return [ev.key, ev.keyPath]

        _triggers.update({
            EventTriggers.ON_OPEN_CHANGE: lambda open_keys: [open_keys],
            EventTriggers.ON_SELECT: _on_select,
            EventTriggers.ON_CLICK: _on_click,
            'on_deselect': _on_click,
        })
        return _triggers


menu = Menu.create
# menu_items = ContainVar.create



from typing import Any, Dict, Literal, Optional, Union, overload
from reflex.vars import Var, BaseVar, ComputedVar
from reflex.event import EventChain, EventHandler, EventSpec
from reflex.style import Style
import uuid
from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from ..base import AntdComponent, ContainVar, JsValue, ReactNode, js_value, memo_never_no_recursive, memo_always_no_recursive
from ..constant import AlignType, DirectionType, SizeType, VariantType

class Form(AntdComponent):

    @overload
    @classmethod
    def create(cls, *children, colon: Optional[Union[Var[bool], bool]]=None, disabled: Optional[Union[Var[bool], bool]]=None, fields: Optional[Union[Var[ContainVar], ContainVar]]=None, form: Optional[Union[Var[str], str]]=None, initial_values: Optional[Union[Var[Dict], Dict]]=None, label_align: Optional[Union[Var[Literal['start', 'end', 'center', 'baseline', 'left', 'right']], Literal['start', 'end', 'center', 'baseline', 'left', 'right']]]=None, label_wrap: Optional[Union[Var[bool], bool]]=None, label_col: Optional[Union[Var[Dict], Dict]]=None, layout: Optional[Union[Var[Literal['vertical', 'horizontal', 'inline']], Literal['vertical', 'horizontal', 'inline']]]=None, name: Optional[Union[Var[str], str]]=None, preserve: Optional[Union[Var[bool], bool]]=None, required_mark: Optional[Union[Var[Union[bool, JsValue]], Union[bool, JsValue]]]=None, scrollTo_first_error: Optional[Union[Var[Union[bool, Dict]], Union[bool, Dict]]]=None, size: Optional[Union[Var[Literal['default', 'small', 'medium', 'middle', 'large']], Literal['default', 'small', 'medium', 'middle', 'large']]]=None, validate_messages: Optional[Union[Var[Dict], Dict]]=None, validate_trigger: Optional[Union[Var[Union[str, List[str]]], Union[str, List[str]]]]=None, variant: Optional[Union[Var[Literal['outlined', 'borderless', 'filled']], Literal['outlined', 'borderless', 'filled']]]=None, wrapper_col: Optional[Union[Var[Dict], Dict]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_fields_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_finish: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_finish_failed: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_values_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Form':
        """"""
        ...

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

class FormItem(AntdComponent):

    @overload
    @classmethod
    def create(cls, *children, colon: Optional[Union[Var[bool], bool]]=None, dependencies: Optional[Union[Var[List[Union[str, int, List[Union[str, int]]]]], List[Union[str, int, List[Union[str, int]]]]]]=None, extra: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, getValue_from_event: Optional[Union[Var[JsValue], JsValue]]=None, get_value_props: Optional[Union[Var[JsValue], JsValue]]=None, has_feedback: Optional[Union[Var[Union[bool, ContainVar]], Union[bool, ContainVar]]]=None, help: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, hidden: Optional[Union[Var[bool], bool]]=None, html_for: Optional[Union[Var[str], str]]=None, initial_value: Optional[Union[Var[str], str]]=None, label: Optional[Union[Var[str], str]]=None, label_align: Optional[Union[Var[Literal['start', 'end', 'center', 'baseline', 'left', 'right']], Literal['start', 'end', 'center', 'baseline', 'left', 'right']]]=None, label_col: Optional[Union[Var[Dict], Dict]]=None, message_variables: Optional[Union[Var[JsValue], JsValue]]=None, name: Optional[Union[Var[Union[str, int, List[Union[str, int]]]], Union[str, int, List[Union[str, int]]]]]=None, normalize: Optional[Union[Var[JsValue], JsValue]]=None, no_style: Optional[Union[Var[bool], bool]]=None, preserve: Optional[Union[Var[bool], bool]]=None, required: Optional[Union[Var[bool], bool]]=None, rules: Optional[Union[Var[List[Dict]], List[Dict]]]=None, should_update: Optional[Union[Var[bool], bool]]=None, tooltip: Optional[Union[Var[Union[Component, ContainVar]], Union[Component, ContainVar]]]=None, trigger: Optional[Union[Var[str], str]]=None, validate_debounce: Optional[Union[Var[float], float]]=None, validate_first: Optional[Union[Var[Union[bool, str]], Union[bool, str]]]=None, validate_status: Optional[Union[Var[str], str]]=None, validate_trigger: Optional[Union[Var[Union[str, List[str]]], Union[str, List[str]]]]=None, value_prop_name: Optional[Union[Var[str], str]]=None, wrapper_col: Optional[Union[Var[Dict], Dict]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'FormItem':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class FormList(AntdComponent):

    @overload
    @classmethod
    def create(cls, *children, initial_value: Optional[Union[Var[List], List]]=None, name: Optional[Union[Var[Union[str, int, List[Union[str, int]]]], Union[str, int, List[Union[str, int]]]]]=None, rules: Optional[Union[Var[ContainVar], ContainVar]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'FormList':
        """Create the component.

        Args:
            *children: The children of the component.
            initial_value: children: Optional[Var[JsValue]]
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class FormProvider(AntdComponent):

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

    @overload
    @classmethod
    def create(cls, *children, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_form_change: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_form_finish: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'FormProvider':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...
form = Form.create
form_item = FormItem.create
form_list = FormList.create
form_provider = FormProvider.create

def modal_form(*children, modal_config=None, form_id: str=None, **props) -> Component:
    ...

def confirm_form(*children, confirm_config=None, form_id: str=None, **props) -> JsValue:
    ...



from reflex import State, Var

from .base import JsValue


def hook_state(state_field: Var | str, on_update: str, on_null: str = '') -> str:
    state = state_field
    if isinstance(state_field, Var):
        state = str(state_field).strip('{}')
    s = """useEffect(() => {
    if (%(state)s === null) { %(on_null)s }
    else { %(on_update)s }
  }, [%(state)s]) """ % dict(
        state=state,
        on_update=on_update,
        on_null=on_null,
    )
    return s



from typing import Optional, Union, Dict, Any, List
from reflex import Var, Component
from reflex.constants import EventTriggers
from reflex.utils import imports

from ..base import AntdComponent, ContainVar, JsValue, JsEvent
from ..constant import StatusType, SizeType


class Table(AntdComponent):
    tag = 'Table'

    bordered: Optional[Var[bool]]
    columns: Optional[Var[Union[ContainVar, list]]]
    data_source: Optional[Var[List[Dict[str, Any]]]]
    expandable: Optional[Var[ContainVar]]
    footer: Optional[Var[JsValue]]
    get_popup_container: Optional[Var[JsValue]]
    loading: Optional[Var[bool]]
    locale: Optional[Var[ContainVar]]
    pagination: Optional[Var[Union[bool, ContainVar]]]
    row_key: Optional[Var[Union[str, JsValue]]]
    row_selection: Optional[Var[ContainVar]]
    scroll: Optional[Var[Union[ContainVar, Dict]]]
    show_header: Optional[Var[bool]]
    show_sorter_tooltip: Optional[Var[Union[bool, ContainVar]]]
    size: Optional[Var[SizeType]] = 'middle'
    sort_directions: Optional[Var[ContainVar]]
    sticky: Optional[Var[Union[bool, JsValue]]]
    summary: Optional[Var[JsValue]]
    table_layout: Optional[Var[str]]
    title: Optional[Var[JsValue]]
    virtual: Optional[Var[bool]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda pagination, filters, sorter: [pagination, filters, sorter],
            'on_header_row': lambda columns, index: [columns, index],
            'on_row': lambda record, index: [record, index],
            'on_scroll': lambda ev: [ev],

            'columns.*.on_header_cell': lambda column: [column],
            'columns.*.on_cell': lambda record, row_index: [record, row_index],
            'columns.*.on_filter': lambda: [],
            'columns.*.on_filter_dropdown_open_change': lambda visible: [visible],

            'pagination.on_change': lambda page, size: [page, size],
            'pagination.on_show_size_change': lambda current, size: [current, size],

            'expandable.on_expand': lambda record, event: [record, event],
            'expandable.on_expanded_rows_change': lambda rows: [rows],

            'row_selection.on_cell': lambda record, index: [record, index],
            'row_selection.on_change': lambda keys, rows, info: [keys, info],
            'row_selection.on_select': lambda record, selected, selected_rows: [record, selected, selected_rows],
            'row_selection.on_select_all':
                lambda selected, selected_rows, change_rows: [selected, selected_rows, change_rows],
        })
        return _triggers


table = Table.create



from typing import Optional, Union, Dict

from reflex import Component, Var
from reflex.utils import imports

from ..base import AntdComponent, ContainVar, ReactNode
from ..constant import AlignType, DirectionType, SizeType


class Space(AntdComponent):
    tag = 'Space'

    align: Optional[Var[AlignType]]
    class_names: Optional[Var[Dict]]
    direction: Optional[Var[DirectionType]]
    size: Optional[Var[SizeType]]
    split: Optional[Var[ReactNode]]
    styles: Optional[Var[Dict]]
    wrap: Optional[Var[bool]]


class SpaceCompact(AntdComponent):
    tag = 'Space.Compact'

    block: Optional[Var[bool]]
    direction: Optional[Var[DirectionType]]
    size: Optional[Var[SizeType]]


space = Space.create
space_compact = SpaceCompact.create




from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import TypeType

class Popconfirm(AntdComponent):
    tag = 'Popconfirm'

    cancel_button_orops: Optional[Var[dict]]
    cancel_text: Optional[Var[str]]
    disabled: Optional[Var[bool]]
    icon: Optional[Var[ReactNode]]
    ok_button_props: Optional[Var[dict]]
    ok_text: Optional[Var[str]]
    ok_type: Optional[Var[TypeType]]
    open: Optional[Var[bool]]
    show_cancel: Optional[Var[bool]]
    title: Optional[Var[ReactNode]]
    description: Optional[Var[ReactNode]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            "on_cancel": lambda e: [e],
            "on_confirm": lambda e: [e],
            "on_popup_click": lambda e: [e],
        })
        return _triggers


popconfirm = Popconfirm.create



from typing import Optional, Union, Dict, Any
from reflex import Var,Component

from ..base import AntdComponent, NodeVar, VarDataMixin
from ..constant import PlacementType, SizeType, BadgeStatusType


class Badge(AntdComponent):
    tag = "Badge"

    color: Optional[Var[str]]
    count: Optional[Var[Union[int, NodeVar]]]
    dot: Optional[Var[bool]]
    offset: Optional[Var[NodeVar]]
    overflow_count: Optional[Var[int]]
    show_zero: Optional[Var[bool]]
    size: Optional[Var[SizeType]]
    status: Optional[Var[BadgeStatusType]]
    text: Optional[Var[Union[str, Component]]]


class BadgeRibbon(AntdComponent):
    tag = 'Badge.Ribbon'

    color: Optional[Var[str]]
    placement: Optional[Var[PlacementType]]
    text: Optional[Var[Union[str, NodeVar]]]


badge = Badge.create
badge_ribbon = BadgeRibbon.create



from .base import stateful, patch_all, default_config, contain, js_value, js_event, container, CasualVar  # noqa
from .antd.base import theme, config_provider, Locale  # noqa
from .util import switch  # noqa





from .antd.auto_complete import auto_complete  # noqa
from .antd.cascader import cascader  # noqa
from .antd.checkbox import checkbox_group, checkbox  # noqa
from .antd.color_picker import color_picker  # noqa
from .antd.date_picker import dayjs, date_picker, range_picker  # noqa
from .antd.form import form, form_item, form_list, form_provider, confirm_form, modal_form  # noqa
from .antd.input import input, text_area, search, password  # noqa
from .antd.input_number import input_number  # noqa
from .antd.mentions import mention  # noqa
from .antd.radio import radio, radio_button, radio_group  # noqa
from .antd.rate import rate  # noqa
from .antd.select import select  # noqa
from .antd.tree_select import tree_select  # noqa
from .antd.slider import slider  # noqa
from .antd.switch import switch  # noqa
from .antd.transfer import transfer  # noqa
from .antd.upload import upload  # noqa





from typing import Optional, Union

from reflex import Component, Var
from reflex.utils import imports

from ..base import AntdComponent, ReactNode
from ..constant import OrientationType, DirectionType


class Divider(AntdComponent):
    tag = 'Divider'

    dashed: Optional[Var[bool]]
    orientation: Optional[Var[OrientationType]]
    orientation_margin: Optional[Var[Union[int, str]]]
    plain: Optional[Var[bool]]
    type: Optional[Var[DirectionType]]


divider = Divider.create




from typing import Optional, Union, Dict, Any

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ReactNode, ContainVar, memo_never
from ..constant import BreakpointType, ThemeType


class LayoutBase(AntdComponent):
    pass


class Layout(LayoutBase):
    tag = 'Layout'

    has_sider: Optional[Var[bool]]

    # def _get_custom_code(self) -> str | None:
    #     return """
    #     const { Header, Content, Footer, Sider } = Layout;
    #     """


class SubLayout(AntdComponent):
    width: Optional[Var[Union[int, str]]]


class Header(SubLayout):
    tag = 'Layout.Header'

    _memoization_mode = memo_never


class Content(SubLayout):
    tag = 'Layout.Content'

    _memoization_mode = memo_never


class Footer(SubLayout):
    tag = 'Layout.Footer'

    _memoization_mode = memo_never


class Sider(SubLayout):
    tag = 'Layout.Sider'

    breakpoint: Optional[Var[Union[BreakpointType, Dict]]]
    collapsed: Optional[Var[bool]]
    collapsed_width: Optional[Var[int]]
    collapsible: Optional[Var[bool]]
    default_collapsed: Optional[Var[bool]]
    reverse_arrow: Optional[Var[bool]]
    theme: Optional[Var[ThemeType]]
    trigger: Optional[Var[ReactNode]]
    zero_width_trigger_style: Optional[Var[Union[Dict, ContainVar]]]

    _memoization_mode = memo_never

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            'on_breakpoint': lambda broken: [broken],
            'on_collapse': lambda collapsed, type: [collapsed, type],
        })
        return _triggers


layout = Layout.create
header = Header.create
content = Content.create
footer = Footer.create
sider = Sider.create




from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import TriggerType, PlacementType, SizeType, StatusType, VariantType


class Cascader(AntdComponent):
    tag = 'Cascader'

    allow_clear: Optional[Var[bool]]
    auto_clear_search_value: Optional[Var[bool]]
    auto_focus: Optional[Var[bool]]
    change_on_select: Optional[Var[bool]]
    default_value: Optional[Var[Union[List[int], List[str]]]]
    disabled: Optional[Var[bool]]
    display_render: Optional[Var[JsValue]]
    tag_render: Optional[Var[JsValue]]
    popup_class_name: Optional[Var[str]]
    dropdown_render: Optional[Var[JsValue]]
    expand_icon: Optional[Var[ReactNode]]
    expand_trigger: Optional[Var[TriggerType]]
    field_names: Optional[Var[ContainVar]]
    get_popup_container: Optional[Var[JsValue]]
    load_data: Optional[Var[JsValue]]
    max_tag_count: Optional[Var[int]]
    max_tag_placeholder: Optional[Var[Union[ReactNode, JsValue]]]
    max_tag_text_length: Optional[Var[int]]
    not_found_content: Optional[Var[str]]
    open: Optional[Var[bool]]
    options: Optional[Var[Union[ContainVar, list]]]
    placeholder: Optional[Var[ReactNode]]
    placement: Optional[Var[PlacementType]]
    show_search: Optional[Var[Union[bool, ContainVar]]]
    size: Optional[Var[SizeType]]
    status: Optional[Var[StatusType]]
    suffix_icon: Optional[Var[ReactNode]]
    value: Optional[Var[Union[List[str], List[int]]]]
    variant: Optional[Var[VariantType]]
    multiple: Optional[Var[bool]]
    remove_icon: Optional[Var[ReactNode]]
    show_checked_strategy: Optional[Var[str]]
    search_value: Optional[Var[str]]
    dropdown_menu_column_style: Optional[Var[ContainVar]]
    loading_icon: Optional[Var[ReactNode]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda value, options: [value, options],
            "on_dropdown_visible_change": lambda value: [value],
            "on_search": lambda search: [search]
        })
        return _triggers


cascader = Cascader.create



from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsNode
from ..constant import OrientationType, DirectionType


class Anchor(AntdComponent):
    tag = 'Anchor'

    affix: Optional[Var[bool]]
    bounds: Optional[Var[int]]
    get_container: Optional[Var[JsNode]]
    get_current_anchor: Optional[Var[JsNode]]
    offset_top: Optional[Var[int]]
    show_ink_in_fixed: Optional[Var[bool]]
    target_offset: Optional[Var[int]]
    items: Optional[Var[Union[List, ContainVar]]]
    direction: Optional[Var[DirectionType]]
    replace: Optional[Var[bool]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()

        _triggers.update({
            EventTriggers.ON_CHANGE: lambda link: [link],
            EventTriggers.ON_CLICK: lambda ev, link: [ev, link],
        })
        return _triggers


anchor = Anchor.create



from typing import Any, Dict, Literal, Optional, Union, overload
from reflex.vars import Var, BaseVar, ComputedVar
from reflex.event import EventChain, EventHandler, EventSpec
from reflex.style import Style
from typing import Optional, Union, Dict, Any
from reflex import Component, Var
from reflex.utils import imports
from reflex.constants import EventTriggers
from ..base import AntdComponent, ReactNode, ContainVar, memo_never
from ..constant import BreakpointType, ThemeType

class LayoutBase(AntdComponent):
    pass

    @overload
    @classmethod
    def create(cls, *children, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'LayoutBase':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Layout(LayoutBase):

    @overload
    @classmethod
    def create(cls, *children, has_sider: Optional[Union[Var[bool], bool]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Layout':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class SubLayout(AntdComponent):

    @overload
    @classmethod
    def create(cls, *children, width: Optional[Union[Var[Union[int, str]], Union[int, str]]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'SubLayout':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Header(SubLayout):

    @overload
    @classmethod
    def create(cls, *children, width: Optional[Union[Var[Union[int, str]], Union[int, str]]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Header':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Content(SubLayout):

    @overload
    @classmethod
    def create(cls, *children, width: Optional[Union[Var[Union[int, str]], Union[int, str]]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Content':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Footer(SubLayout):

    @overload
    @classmethod
    def create(cls, *children, width: Optional[Union[Var[Union[int, str]], Union[int, str]]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Footer':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class Sider(SubLayout):

    def get_event_triggers(self) -> Dict[str, Any]:
        ...

    @overload
    @classmethod
    def create(cls, *children, breakpoint: Optional[Union[Var[Union[Literal['xs', 'sm', 'md', 'lg', 'xl', 'xxl'], Dict]], Union[Literal['xs', 'sm', 'md', 'lg', 'xl', 'xxl'], Dict]]]=None, collapsed: Optional[Union[Var[bool], bool]]=None, collapsed_width: Optional[Union[Var[int], int]]=None, collapsible: Optional[Union[Var[bool], bool]]=None, default_collapsed: Optional[Union[Var[bool], bool]]=None, reverse_arrow: Optional[Union[Var[bool], bool]]=None, theme: Optional[Union[Var[Literal['light', 'dark']], Literal['light', 'dark']]]=None, trigger: Optional[Union[Var[Union[str, Component]], Union[str, Component]]]=None, zero_width_trigger_style: Optional[Union[Var[Union[Dict, ContainVar]], Union[Dict, ContainVar]]]=None, width: Optional[Union[Var[Union[int, str]], Union[int, str]]]=None, _custom_components: Optional[Set[CustomComponent]]=None, style: Optional[Style]=None, key: Optional[Any]=None, id: Optional[Any]=None, class_name: Optional[Any]=None, autofocus: Optional[bool]=None, custom_attrs: Optional[Dict[str, Union[Var, str]]]=None, on_blur: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_breakpoint: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_collapse: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_context_menu: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_double_click: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_focus: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_down: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_enter: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_leave: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_move: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_out: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_over: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_mouse_up: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_scroll: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, on_unmount: Optional[Union[EventHandler, EventSpec, list, function, BaseVar]]=None, **props) -> 'Sider':
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            class_name: The class name for the component.
            autofocus: Whether the component should take the focus once the page is loaded
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...
layout = Layout.create
header = Header.create
content = Content.create
footer = Footer.create
sider = Sider.create


from typing import Optional, Union, Dict, Any
from reflex import Var, Component
from reflex.constants import EventTriggers

from ..base import AntdComponent, ContainVar, JsValue, ReactNode
from ..constant import StatusType, SizeType, VariantType


class Input(AntdComponent):
    tag = "Input"

    addon_after: Optional[Var[ReactNode]]
    addon_before: Optional[Var[ReactNode]]
    allow_clear: Optional[Var[Union[bool, ContainVar]]]
    count: Optional[Var[Union[Dict, ContainVar]]]
    default_value: Optional[Var[str]]
    disabled: Optional[Var[bool]]
    id: Optional[Var[str]]
    max_length: Optional[Var[int]]
    prefix: Optional[Var[ReactNode]]
    show_count: Optional[Var[Union[bool, JsValue]]]
    status: Optional[Var[StatusType]]
    size: Optional[Var[SizeType]]
    suffix: Optional[Var[ReactNode]]
    type: Optional[Var[str]]
    value: Optional[Var[str]]
    variant: Optional[Var[VariantType]]
    placeholder: Optional[Var[str]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            EventTriggers.ON_CHANGE: lambda e: [e],
            'on_press_enter': lambda e: [e],
        })
        return _triggers


class TextArea(Input):
    tag = "Input.TextArea"

    auto_size: Optional[Var[Union[bool, Dict]]]


class Search(Input):
    tag = 'Input.Search'

    enter_button: Optional[Var[ReactNode]]
    loading: Optional[Var[bool]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            'on_search': lambda value, event, info: [value],
        })
        return _triggers


class Password(Input):
    tag = 'Input.Password'

    icon_render: Optional[Var[JsValue]]
    visibility_toggle: Optional[Var[Union[bool, ContainVar]]]


input = Input.create  # noqa
text_area = TextArea.create
search = Search.create
password = Password.create






from typing import List, Tuple, Any, Callable
import collections

import reflex as rx


def switch(
        val: rx.Var,
        values: List[Tuple[Callable[[rx.Var, ], rx.Var] | str, rx.Component | Callable[..., rx.Component]]],
        default: rx.Component | Callable[..., rx.Component] = None,
) -> rx.Component | None:
    """
    chain cond, like:
    cond(condition1, com1,
        cond(condition2, com2,
            cond(condition3, com3, default)
        )
    )
     """
    conds = None
    for v in reversed(values):
        _op, _com = v
        _cond = _op(val) if callable(_op) else val == _op
        if conds is not None:
            conds = rx.cond(_cond, _com, conds)
        else:
            conds = rx.cond(_cond, _com, default)
    return conds


class OrderedSet(collections.abc.MutableSet):

    def __init__(self, iterable=None):
        self.end = end = []
        end += [None, end, end]         # sentinel node for doubly linked list
        self.map = {}                   # key --> [key, prev, next]
        if iterable is not None:
            self |= iterable

    def __len__(self):
        return len(self.map)

    def __contains__(self, key):
        return key in self.map

    def add(self, key):
        if key not in self.map:
            end = self.end
            curr = end[1]
            curr[2] = end[1] = self.map[key] = [key, curr, end]

    def discard(self, key):
        if key in self.map:
            key, prev, next = self.map.pop(key)
            prev[2] = next
            next[1] = prev

    def __iter__(self):
        end = self.end
        curr = end[2]
        while curr is not end:
            yield curr[0]
            curr = curr[2]

    def __reversed__(self):
        end = self.end
        curr = end[1]
        while curr is not end:
            yield curr[0]
            curr = curr[1]

    def pop(self, last=True):
        if not self:
            raise KeyError('set is empty')
        key = self.end[1][0] if last else self.end[2][0]
        self.discard(key)
        return key

    def __repr__(self):
        if not self:
            return '%s()' % (self.__class__.__name__,)
        return '%s(%r)' % (self.__class__.__name__, list(self))

    def __eq__(self, other):
        if isinstance(other, OrderedSet):
            return len(self) == len(other) and list(self) == list(other)
        return set(self) == set(other)




from typing import Optional, Union, Dict, Any, List

from reflex import Component, Var

from ..base import AntdComponent, ContainVar, JsValue, ReactNode


class Collapse(AntdComponent):
    tag = 'Collapse'

    accordion: Optional[Var[bool]]
    active_key: Optional[Var[Union[list[str], str, list[int], int]]]
    bordered: Optional[Var[bool]]
    default_active_key: Optional[Var[Union[list[str], str, list[int], int]]]
    destroy_inactive_panel: Optional[Var[bool]]
    expand_icon: Optional[Var[ReactNode]]
    collapsible: Optional[Var[str]]
    expand_icon_position: Optional[Var[str]]
    ghost: Optional[Var[bool]]
    size: Optional[Var[str]]
    items: Optional[Var[Union[ContainVar, list]]]

    def get_event_triggers(self) -> Dict[str, Any]:
        _triggers = super().get_event_triggers()
        _triggers.update({
            'on_change': lambda: [],
        })
        return _triggers


collapse = Collapse.create
